/*
 * This file is a part of KEMET project (Library).
 * 
 * Copyright (C) 2008 MAUPIN Fabrice
 *
 * This library is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation; 
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this library; 
 * if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 */
package org.kemet.tests.integration.transliteration;

import org.apache.log4j.Logger;
import org.junit.Test;
import org.kemet.impl.grammar.exceptions.KemetAPIException;
import org.kemet.impl.grammar.integration.TransliterationManager;
import org.kemet.tests.TestRoot;

/**
 * 
 * @author fabricemaupin
 * 
 * <p>
 * <b>integration tests : analyze type of translitered sequence - output : list
 * of translitered sequence.</b>
 * </p>
 * 
 * support : uniliteral, biliteral, triliteral, indicator of ppa, pronoun
 * 
 * @since 0.5
 * 
 */
public class TestsToTransliteration extends TestRoot {
	static final Logger log = Logger.getLogger("org.kemet.tests");

	/**
	 * <p>
	 * <b>initialize the parameters before to execute the tests.</b>
	 * </p>
	 * 
	 * @since 0.5
	 */
	public void init() {
		// nothing
	}

	/**
	 * <p>
	 * <b>indicator of ppa + demonstrative pronoun + biliteral + uniliteral +
	 * triliteral + uniliteral.</b>
	 * </p>
	 * 
	 * @since 0.5
	 */
	@Test
	public void test1() {
		// initialize the data tests
		sequence = "jwnnc3cjm33";
		result = new String[] { "jw", "nn", "c3", "c", "jm3", "3" };

		transliteration = new TransliterationManager(sequence, gm, phInfo,
				sortedPhInfo, TO_TRANSLITERATION);

		String[] res;
		try {
			res = transliteration.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			assertTrue(false);
		}
	}
}
